@@ -41,8 +41,6 @@
 
 #define PLASMAQUICK_DECL_DEPRECATED_TEXT(text) __attribute__ ((__deprecated__(text)))
 
-#define ECM_GENERATEEXPORTHEADER_VERSION_VALUE(major, minor, patch) ((major<<16)|(minor<<8)|(patch))
-
 /* Take any defaults from group settings */
 #if !defined(PLASMAQUICK_NO_DEPRECATED) && !defined(PLASMAQUICK_DISABLE_DEPRECATED_BEFORE_AND_AT)
 #  ifdef KF_NO_DEPRECATED
@@ -86,7 +84,7 @@
 #define PLASMAQUICK_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef PLASMAQUICK_NO_DEPRECATED
-#  define PLASMAQUICK_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56900
+#  define PLASMAQUICK_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56a00
 #endif
 #ifdef PLASMAQUICK_NO_DEPRECATED_WARNINGS
 #  define PLASMAQUICK_DEPRECATED_WARNINGS_SINCE 0
@@ -96,7 +94,7 @@
 #  ifdef PLASMAQUICK_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define PLASMAQUICK_DEPRECATED_WARNINGS_SINCE PLASMAQUICK_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define PLASMAQUICK_DEPRECATED_WARNINGS_SINCE 0x56900
+#    define PLASMAQUICK_DEPRECATED_WARNINGS_SINCE 0x56a00
 #  endif
 #endif
 
@@ -105,7 +103,7 @@
 #endif
 
 #ifdef PLASMAQUICK_DEPRECATED
-#  define PLASMAQUICK_ENABLE_DEPRECATED_SINCE(major, minor) (ECM_GENERATEEXPORTHEADER_VERSION_VALUE(major, minor, 0) > PLASMAQUICK_DISABLE_DEPRECATED_BEFORE_AND_AT)
+#  define PLASMAQUICK_ENABLE_DEPRECATED_SINCE(major, minor) (((major<<16)|(minor<<8)) > PLASMAQUICK_DISABLE_DEPRECATED_BEFORE_AND_AT)
 #else
 #  define PLASMAQUICK_ENABLE_DEPRECATED_SINCE(major, minor) 0
 #endif
